<?php

namespace Drupal\commerce_stripe_payment_request_button\Controller;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class PaymentRequestButtonCheckout  {

  public function handleOrder(Request $request) {
    // Transform JSON values to array
    $values = Json::decode($request->getContent());
    $order_id = $values["data"]["order_id"];

    $carts = \Drupal::getContainer()->get('commerce_cart.cart_provider')->getCarts();
    $active_cart = array_filter($carts, function (OrderInterface $cart) use ($order_id) {
      return $cart->id() == $order_id;
    });


    // Form values are passed as a serialized string.
    $form_values = [];
    parse_str($values["data"]["serialized_form"], $form_values);

    // Init Stripe.
    //TODO below is hardcoded config value, we need to fix this to be variable or enforced in config form
    $config = \Drupal::config('commerce_payment.commerce_payment_gateway.stripe_pbtt')
      ->get('configuration');

    \Stripe\Stripe::setApiKey( $config['secret_key']);
    $active_cart = reset($active_cart);

    // @see \Drupal\commerce_checkout\Controller\CheckoutController::checkAccess
    if (empty($active_cart) || $active_cart->getState()->value == 'canceled') {
      $response = [
        'redirect_uri' => Url::fromRoute(Url::fromRoute('commerce_cart.page')->toString()),
      ];
      return new JsonResponse($response);
    }


    try {
      // Charge the user's card immediately.
      $charge = \Stripe\Charge::create([
        'amount' => $values["data"]["payment_request"]["total"]["amount"],
        'currency' => $values["data"]["payment_request"]["currency"],
        'description' => $values["data"]["payment_request"]["total"]["label"],
        'metadata' => ["order_id" => $values["data"]["order_id"]],
        'source' => $values["data"]["token"],
      ]);
    }
    catch (\Stripe\Error\Base $e) {

      watchdog_exception('commerce_stripe_payment_request', $e);
      // Server will return 500 to the frontend.
      \Drupal::messenger()->addError($e->getMessage());
    }



  if ($active_cart->hasItems()) {
     // $active_cart->setEmail($user_information['email']);
      $active_cart->get('checkout_flow')->setValue(NULL);
      $active_cart->get('checkout_step')->setValue("payment");
      $active_cart->get('payment_gateway')->setValue("commerce_stripe_payment_request_button");
      $active_cart->save();
    }

    //TODO go to proper checkout page, process or complete
    $response = [
      'redirect_uri' => Url::fromRoute('commerce_checkout.form', [
        'commerce_order' => $active_cart->id(),
      ])->toString(),
    ];


    return new JsonResponse($response);
  }



}
